@@ -1,6 +1,6 @@
 /*
  *  Bubbling Load Monitoring Applet
- *  Copyright (C) 1999-2004 Johan Walles - johan.walles@gmail.com
+ *  Copyright (C) 1999-2004, 2008 Johan Walles - johan.walles@gmail.com
  *  http://www.nongnu.org/bubblemon/
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -22,15 +22,17 @@
  * This is a platform independent file that drives the program.
  */
 
-#include <config.h> 
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <assert.h>
 #include <sys/time.h>
 #include <string.h>
-#include <math.h>
 #include <time.h>
 
+#include <math.h>
+double exp2(double x);
+
 #include "bubblemon.h"
 #include "ui.h"
 #include "meter.h"
@@ -52,31 +54,31 @@ void bubblemon_setSize(int width, int height)
   {
     bubblePic.width = width;
     bubblePic.height = height;
-    
+
     if (bubblePic.airAndWater != NULL)
     {
       free(bubblePic.airAndWater);
       bubblePic.airAndWater = NULL;
     }
-    
+
     if (bubblePic.pixels != NULL)
     {
       free(bubblePic.pixels);
       bubblePic.pixels = NULL;
     }
-    
+
     if (physics.waterLevels != NULL)
     {
       free(physics.waterLevels);
       physics.waterLevels = NULL;
     }
-    
+
     if (physics.weeds != NULL)
     {
       free(physics.weeds);
       physics.weeds = NULL;
     }
-    
+
     physics.n_bubbles = 0;
     physics.max_bubbles = 0;
     if (physics.bubbles != NULL)
@@ -87,49 +89,72 @@ void bubblemon_setSize(int width, int height)
   }
 }
 
-static void usage2string(/*@out@*/ char *string,
+static void usage2string(char *string,
 			 u_int64_t used,
 			 u_int64_t max)
 {
   /* Create a string of the form "35/64Mb" */
-  
-  unsigned int shiftme = 0;
-  char divisor_char = '\0';
+
+  unsigned int shiftme;
+  char usageString[10];
+  char maxString[10];
+
+  // We have this to be able to store either a constant string or a
+  // dynamically created one in the same variable (unit).
+  char *unit;
+  char unitString[10];
+  unit = unitString;
 
   if ((max >> 30) > 7000)
     {
       shiftme = 40;
-      divisor_char = 'T';
+      unit = "Tb";
     }
   else if ((max >> 20) > 7000)
     {
       shiftme = 30;
-      divisor_char = 'G';
+      unit = "Gb";
     }
   else if ((max >> 10) > 7000)
     {
       shiftme = 20;
-      divisor_char = 'M';
+      unit = "Mb";
     }
   else if ((max >> 0) > 7000)
     {
       shiftme = 10;
-      divisor_char = 'k';
-    }
-
-  if (divisor_char == '\0')
-    {
-      sprintf(string, _("%llu/%llu bytes"),
-	      used >> shiftme,
-	      max >> shiftme);
+      unit = "kb";
     }
   else
     {
-      sprintf(string, _("%llu/%llu%cb"),
-	      used >> shiftme,
-	      max >> shiftme,
-	      divisor_char);
+      shiftme = 0;
+      sprintf(unit, " %s", _("bytes"));
     }
+
+  if ((used >> shiftme) < 10) {
+    // Print usage number with one decimal digit
+    double doubleUsage = used / exp2((double)shiftme);
+
+    sprintf(usageString, "%'.1f", doubleUsage);
+  } else {
+    // Print integer usage
+    sprintf(usageString, "%llu", used >> shiftme);
+  }
+
+  if ((max >> shiftme) < 10) {
+    // Print total memory number with one decimal digit
+    double doubleMax = max / exp2((double)shiftme);
+
+    sprintf(maxString, "%'.1f", doubleMax);
+  } else {
+    // Print total memory as an integer
+    sprintf(maxString, "%llu", max >> shiftme);
+  }
+
+  sprintf(string, "%s/%s%s",
+	  usageString,
+	  maxString,
+	  unit);
 }
 
 const char *bubblemon_getTooltip(void)
@@ -180,7 +205,7 @@ const char *bubblemon_getTooltip(void)
           strcat(tooltipstring, loadstring);
         }
     }
-  
+
   return tooltipstring;
 }
 
@@ -198,7 +223,7 @@ static int bubblemon_getMsecsSinceLastCall()
 
   /* What time is it now? */
   gettimeofday(&currentTime, NULL);
-  
+
   if ((last_sec != 0L) || (last_usec != 0L))
   {
     returnMe = 1000 * (int)(currentTime.tv_sec - last_sec);
@@ -218,30 +243,35 @@ static void bubblemon_updateWaterlevels(int msecsSinceLastCall)
   /* Typing fingers savers */
   int w = bubblePic.width;
   int h = bubblePic.height;
-  
+
   int x;
-  
+
   /* Where is the surface heading? */
   float waterLevels_goal;
 
   /* How high can the surface be? */
   float waterLevels_max = (h - 0.55);
-  
+
   /* Move the water level with the current memory usage.  The water
    * level goes from 0.0 to h so that you can get an integer height by
    * just chopping off the decimals. */
   waterLevels_goal =
     ((float)sysload.memoryUsed / (float)sysload.memorySize) * waterLevels_max;
-  
+  if (waterLevels_goal < 3.4) {
+    // If the water level is too low, the CPU load bubbles won't be
+    // visible.  Enforce a minimum water level. /JW-2008dec28
+    waterLevels_goal = 3.4;
+  }
+
   physics.waterLevels[0].y = waterLevels_goal;
   physics.waterLevels[w - 1].y = waterLevels_goal;
-  
+
   for (x = 1; x < (w - 1); x++)
   {
     /* Accelerate the current waterlevel towards its correct value */
     float current_waterlevel_goal = (physics.waterLevels[x - 1].y +
 				     physics.waterLevels[x + 1].y) / 2.0;
-    
+
     physics.waterLevels[x].dy +=
       (current_waterlevel_goal - physics.waterLevels[x].y) * dt * VOLATILITY;
 
@@ -252,12 +282,12 @@ static void bubblemon_updateWaterlevels(int msecsSinceLastCall)
     else if (physics.waterLevels[x].dy < -SPEED_LIMIT)
       physics.waterLevels[x].dy = -SPEED_LIMIT;
   }
-  
+
   for (x = 1; x < (w - 1); x++)
   {
     /* Move the current water level */
     physics.waterLevels[x].y += physics.waterLevels[x].dy * dt;
-    
+
     if (physics.waterLevels[x].y > waterLevels_max)
     {
       /* Stop the wave if it hits the ceiling... */
@@ -276,9 +306,9 @@ static void bubblemon_updateWaterlevels(int msecsSinceLastCall)
 static void bubblemon_addNourishment(bubblemon_Weed *weed, int percentage)
 {
   float heightLimit = (bubblePic.height * WEED_HEIGHT) / 100.0;
-  
+
   weed->nourishment += (heightLimit * percentage) / 100.0;
-  
+
   if (weed->nourishment + weed->height > heightLimit)
   {
     weed->nourishment = heightLimit - weed->height;
@@ -298,7 +328,7 @@ static void bubblemon_updateWeeds(int msecsSinceLastCall)
   {
     // ... update the nourishment level of our next weed
     int weed = random() % bubblePic.width;
-    
+
     // Distribute the nourishment over several weeds
     if (weed > 0)
     {
@@ -309,17 +339,17 @@ static void bubblemon_updateWeeds(int msecsSinceLastCall)
     {
       bubblemon_addNourishment(&(physics.weeds[weed + 1]), (netload_getLoadPercentage() * 8) / 10);
     }
-    
+
     timeToNextUpdate += NETLOAD_INTERVAL;
   }
-  
+
   // For all weeds...
   for (x = 0; x < w; x++)
   {
     // ... grow / shrink them according to their nourishment level
     float speed;
     float delta;
-    
+
     if (physics.weeds[x].nourishment <= 0.0)
     {
       speed = -WEED_MINSPEED;
@@ -336,13 +366,13 @@ static void bubblemon_updateWeeds(int msecsSinceLastCall)
 	speed = WEED_MINSPEED;
       }
     }
-    
+
     delta = (speed * msecsSinceLastCall) / 1000.0;
     if (delta > physics.weeds[x].nourishment)
     {
       delta = physics.weeds[x].nourishment;
     }
-    
+
     if (delta > 0.0)
     {
       physics.weeds[x].nourishment -= delta;
@@ -366,7 +396,7 @@ static void bubblemon_createBubble(int x, bubblemon_layer_t layer)
   /* We don't allow bubbles on the edges 'cause we'd have to clip them */
   assert(x >= 1);
   assert(x <= bubblePic.width - 2);
-  
+
   if (physics.n_bubbles < physics.max_bubbles)
   {
     physics.bubbles[physics.n_bubbles].x = x;
@@ -374,7 +404,7 @@ static void bubblemon_createBubble(int x, bubblemon_layer_t layer)
     physics.bubbles[physics.n_bubbles].dy = 0.0;
     /* Create alternately foreground and background bubbles */
     physics.bubbles[physics.n_bubbles].layer = layer;
-    
+
     if (RIPPLES != 0.0)
     {
       /* Raise the water level above where the bubble is created */
@@ -386,7 +416,7 @@ static void bubblemon_createBubble(int x, bubblemon_layer_t layer)
       if ((physics.bubbles[physics.n_bubbles].x + 2) < bubblePic.width)
 	physics.waterLevels[physics.bubbles[physics.n_bubbles].x + 2].y += RIPPLES;
     }
-    
+
     /* Count the new bubble */
     physics.n_bubbles++;
   }
@@ -415,7 +445,7 @@ static void bubblemon_createBubbles(int msecsSinceLastCall)
     createNNewBubbles = calloc(sysload.nCpus, sizeof(float));
     assert(createNNewBubbles != NULL);
   }
-  
+
   static int *sortedCpuLoads;
   if (sortedCpuLoads == NULL) {
     sortedCpuLoads = calloc(sysload.nCpus, sizeof(int));
@@ -430,22 +460,21 @@ static void bubblemon_createBubbles(int msecsSinceLastCall)
     sortedCpuLoads[cpu] = bubblemon_getCpuLoadPercentage(cpu);
   }
   qsort(sortedCpuLoads, sysload.nCpus, sizeof(*sortedCpuLoads), intCompare);
-  
+
   float dt = msecsSinceLastCall / 30.0;
 
   // We have this many pixels for bubble rendering.  Don't allow
   // bubbles on the edges because clipping is boring.
   float allCandidatePixels = bubblePic.width - 2;
   float perCpuCandidatePixels = allCandidatePixels / (float)sysload.nCpus;
-  
+
   // For each CPU...
   for (cpu = 0; cpu < sysload.nCpus; cpu++) {
     // ... should we create any bubbles?
-    float width = bubblePic.width;
     createNNewBubbles[cpu] += ((float)sortedCpuLoads[cpu] *
 			       perCpuCandidatePixels *
 			       dt) / 2000.0;
-    
+
     while (createNNewBubbles[cpu] >= 1.0) {
       // Yes!  Bubbles needed.
 
@@ -468,7 +497,7 @@ static void bubblemon_createBubbles(int msecsSinceLastCall)
       bubblemon_layer_t layer =
 	random() % 120 < sortedCpuLoads[cpu] ? FOREGROUND : BACKGROUND;
       bubblemon_createBubble(x + 1.0, layer);
-      
+
       // Count the new bubble
       createNNewBubbles[cpu]--;
     }
@@ -479,7 +508,7 @@ static void bubblemon_createBubbles(int msecsSinceLastCall)
 static void bubblemon_updateBubbles(int msecsSinceLastCall)
 {
   bubblemon_createBubbles(msecsSinceLastCall);
-  
+
   /* Move the bubbles */
   int i;
   float dt = msecsSinceLastCall / 30.0;
@@ -487,12 +516,12 @@ static void bubblemon_updateBubbles(int msecsSinceLastCall)
   {
     /* Accelerate the bubble upwards */
     physics.bubbles[i].dy -= GRAVITY * dt;
-    
+
     /* Move the bubble vertically */
     physics.bubbles[i].y +=
       physics.bubbles[i].dy * dt *
       ((physics.bubbles[i].layer == BACKGROUND) ? BGBUBBLE_SPEED : 1.0);
-    
+
     /* Did we lose it? */
     if (physics.bubbles[i].y > physics.waterLevels[physics.bubbles[i].x].y)
     {
@@ -504,13 +533,13 @@ static void bubblemon_updateBubbles(int msecsSinceLastCall)
         physics.waterLevels[physics.bubbles[i].x].y     -= 3 * RIPPLES;
         physics.waterLevels[physics.bubbles[i].x + 1].y -= RIPPLES;
       }
-      
+
       /* We just lost it, so let's nuke it */
       physics.bubbles[i].x  = physics.bubbles[physics.n_bubbles - 1].x;
       physics.bubbles[i].y  = physics.bubbles[physics.n_bubbles - 1].y;
       physics.bubbles[i].dy = physics.bubbles[physics.n_bubbles - 1].dy;
       physics.n_bubbles--;
-      
+
       /* We must check the previously last bubble, which is
         now the current bubble, also. */
       i--;
@@ -584,10 +613,10 @@ static void bubblemon_updateBottle(int msecsSinceLastCall,
   }
 
   physics.bottle_dy += gravityDdy + dragDdy;
-  
+
   /* Move the bottle vertically */
   physics.bottle_y += physics.bottle_dy * dt;
-  
+
   // If the bottle has fallen on screen...
   if ((physics.bottle_state == FALLING) &&
       (physics.bottle_y < bubblePic.height))
@@ -595,7 +624,7 @@ static void bubblemon_updateBottle(int msecsSinceLastCall,
     // ... it should start floating instead of falling
     physics.bottle_state = FLOATING;
   }
-  
+
   /* Did it hit bottom? */
   if (physics.bottle_state == SINKING) {
     if ((mailStatus == READ_MAIL)
@@ -612,15 +641,15 @@ static void bubblemon_updateBottle(int msecsSinceLastCall,
 }
 
 
-static const bubblemon_color_t bubblemon_constant2color(const unsigned int constant)
+static bubblemon_color_t bubblemon_constant2color(const unsigned int constant)
 {
   bubblemon_color_t returnMe;
-  
+
   returnMe.components.r = (constant >> 24) & 0xff;
-  returnMe.components.g = (constant >> 16) & 0xff; 
-  returnMe.components.b = (constant >> 8)  & 0xff; 
+  returnMe.components.g = (constant >> 16) & 0xff;
+  returnMe.components.b = (constant >> 8)  & 0xff;
   returnMe.components.a = (constant >> 0)  & 0xff;
-  
+
   return returnMe;
 }
 
@@ -658,7 +687,7 @@ static inline bubblemon_color_t bubblemon_interpolateColor(const bubblemon_color
   assert(((c1.components.b <= b) && (b <= c2.components.b)) ||
 	 ((c1.components.b >= b) && (b >= c2.components.b)));
   */
-  
+
   returnme.components.r = r;
   returnme.components.g = g;
   returnme.components.b = b;
@@ -682,7 +711,7 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
     assert(bubblePic.airAndWater == NULL);
     return;
   }
-  
+
   /* Make sure the water levels exist */
   if (physics.waterLevels == NULL)
   {
@@ -690,12 +719,12 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
       (bubblemon_WaterLevel *)calloc(bubblePic.width, sizeof(bubblemon_WaterLevel));
     assert(physics.waterLevels != NULL);
   }
-  
+
   /* Make sure the sea-weeds exist */
   if (physics.weeds == NULL)
   {
     int i;
-    
+
     physics.weeds =
       (bubblemon_Weed *)calloc(bubblePic.width, sizeof(bubblemon_Weed));
     assert(physics.weeds != NULL);
@@ -704,7 +733,7 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
     for (i = 0; i < bubblePic.width; i++)
     {
       static int stripey = 0;
-      
+
       physics.weeds[i].color =
 	bubblemon_interpolateColor(bubblemon_constant2color(WEEDCOLOR0),
 				   bubblemon_constant2color(WEEDCOLOR1),
@@ -712,7 +741,7 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
       stripey = 100 - stripey;
     }
   }
-  
+
   /* Make sure the bubbles exist */
   if (physics.bubbles == NULL)
   {
@@ -720,12 +749,12 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
     // FIXME: max_bubbles should be the width * the time it takes for
     // a bubble to rise all the way to the ceiling.
     physics.max_bubbles = (bubblePic.width * bubblePic.height) / 5;
-    
+
     physics.bubbles =
       (bubblemon_Bubble *)calloc(physics.max_bubbles, sizeof(bubblemon_Bubble));
     assert(physics.bubbles != NULL);
   }
-  
+
   /* Update our universe */
   bubblemon_updateWaterlevels(msecsSinceLastCall);
   bubblemon_updateWeeds(msecsSinceLastCall);
@@ -736,7 +765,7 @@ static void bubblemon_updatePhysics(int msecsSinceLastCall,
 int bubblemon_getMemoryPercentage()
 {
   int returnme;
-  
+
   if (sysload.memorySize == 0L)
   {
     returnme = 0;
@@ -756,7 +785,7 @@ int bubblemon_getMemoryPercentage()
 int bubblemon_getSwapPercentage()
 {
   int returnme;
-  
+
   if (sysload.swapSize == 0L)
   {
     returnme = 0;
@@ -777,7 +806,7 @@ int bubblemon_getSwapPercentage()
 int bubblemon_getCpuLoadPercentage(int cpuNo)
 {
   assert(cpuNo >= 0 && cpuNo < sysload.nCpus);
-  
+
 #ifdef ENABLE_PROFILING
   return 100;
 #else
@@ -789,7 +818,7 @@ int bubblemon_getAverageLoadPercentage()
 {
   int cpuNo;
   int totalLoad;
-  
+
   totalLoad = 0;
   for (cpuNo = 0; cpuNo < sysload.nCpus; cpuNo++)
   {
@@ -814,7 +843,7 @@ static void bubblemon_censorLoad()
      relative to the total amount of electronic RAM.  The swap color
      indicates how much memory above the amount of electronic RAM the
      system is using.
-    
+
      This scheme does *not* show how the system has decided to
      allocate swap and electronic RAM to the users' processes.
   */
@@ -857,13 +886,13 @@ static void bubblemon_draw_bubble(/*@out@*/ bubblemon_picture_t *bubblePic,
   int w = bubblePic->width;
   int h = bubblePic->height;
   bubblemon_colorcode_t *buf_ptr;
-  
+
   /*
     Clipping is not necessary for x, but it is for y.
     To prevent ugliness, we draw aliascolor only on top of
     watercolor, and aircolor on top of aliascolor.
   */
-  
+
   /* Top row */
   buf_ptr = &(bubbleBuf[(y - 1) * w + x - 1]);
   if (y > 0)
@@ -873,9 +902,9 @@ static void bubblemon_draw_bubble(/*@out@*/ bubblemon_picture_t *bubblePic,
       (*buf_ptr)++ ;
     }
     buf_ptr++;
-    
+
     *buf_ptr = AIR; buf_ptr++;
-    
+
     if (*buf_ptr != AIR)
     {
       (*buf_ptr)++ ;
@@ -886,12 +915,12 @@ static void bubblemon_draw_bubble(/*@out@*/ bubblemon_picture_t *bubblePic,
   {
     buf_ptr += w;
   }
-  
+
   /* Middle row - no clipping necessary */
   *buf_ptr = AIR; buf_ptr++;
   *buf_ptr = AIR; buf_ptr++;
   *buf_ptr = AIR; buf_ptr += (w - 2);
-  
+
   /* Bottom row */
   if (y < (h - 1))
   {
@@ -900,9 +929,9 @@ static void bubblemon_draw_bubble(/*@out@*/ bubblemon_picture_t *bubblePic,
       (*buf_ptr)++ ;
     }
     buf_ptr++;
-    
+
     *buf_ptr = AIR; buf_ptr++;
-    
+
     if (*buf_ptr != AIR)
     {
       (*buf_ptr)++ ;
@@ -926,7 +955,7 @@ static void bubblemon_environmentToBubbleArray(bubblemon_picture_t *bubblePic,
     bubblePic->airAndWater = (bubblemon_colorcode_t *)malloc(w * h * sizeof(bubblemon_colorcode_t));
     assert(bubblePic->airAndWater != NULL);
   }
-  
+
   // Draw the air and water background
   for (x = 0; x < w; x++)
   {
@@ -960,7 +989,7 @@ static void bubblemon_environmentToBubbleArray(bubblemon_picture_t *bubblePic,
       pixel += w;
     }
   }
-  
+
   // Draw the bubbles
   bubble = physics.bubbles;
   hf = h; // Move the int->float cast out of the loop
@@ -984,28 +1013,28 @@ static void bubblemon_bubbleArrayToPixmap(bubblemon_picture_t *bubblePic,
 
   static bubblemon_color_t maxSwapAirColor;
   static bubblemon_color_t maxSwapWaterColor;
-  
+
   bubblemon_color_t colors[3];
-  
+
   bubblemon_colorcode_t *airOrWater;
   bubblemon_color_t *pixel;
   int i;
-  
+
   int w, h;
-  
+
   noSwapAirColor = bubblemon_constant2color(NOSWAPAIRCOLOR);
   noSwapWaterColor = bubblemon_constant2color(NOSWAPWATERCOLOR);
 
   maxSwapAirColor = bubblemon_constant2color(MAXSWAPAIRCOLOR);
   maxSwapWaterColor = bubblemon_constant2color(MAXSWAPWATERCOLOR);
-  
+
   colors[AIR] = bubblemon_interpolateColor(noSwapAirColor, maxSwapAirColor, (bubblemon_getSwapPercentage() * 255) / 100);
   colors[WATER] = bubblemon_interpolateColor(noSwapWaterColor, maxSwapWaterColor, (bubblemon_getSwapPercentage() * 255) / 100);
   colors[ANTIALIAS] = bubblemon_interpolateColor(colors[AIR], colors[WATER], 128);
-  
+
   w = bubblePic->width;
   h = bubblePic->height;
-  
+
   /* Make sure the pixel array exist */
   if (bubblePic->pixels == NULL)
   {
@@ -1013,7 +1042,7 @@ static void bubblemon_bubbleArrayToPixmap(bubblemon_picture_t *bubblePic,
       (bubblemon_color_t *)malloc(bubblePic->width * bubblePic->height * sizeof(bubblemon_color_t));
     assert(bubblePic->pixels != NULL);
   }
-  
+
   pixel = bubblePic->pixels;
   airOrWater = bubblePic->airAndWater;
   if (layer == BACKGROUND) {
@@ -1040,30 +1069,30 @@ static void bubblemon_bottleToPixmap(bubblemon_picture_t *bubblePic)
   int bottleYMin, bottleYMax;
   int pictureX0, pictureY0;
   int pictureW, pictureH;
-  
+
   if (physics.bottle_state == GONE) {
     return;
   }
-  
+
   assert(bubblePic->pixels != NULL);
-  
+
   pictureW = bubblePic->width;
   pictureH = bubblePic->height;
-  
+
   bottleW = msgInBottle.width;
   bottleH = msgInBottle.height;
-  
+
   // Ditch the bottle if the image is too small
   // FIXME: Should we check the image height as well?
   if (pictureW < (bottleW + 4)) {
     return;
   }
-  
+
   // Center the bottle horizontally
   pictureX0 = (bubblePic->width - bottleW) / 2;
   // Position the bottle vertically
   pictureY0 = pictureH - physics.bottle_y - bottleH / 2;
-  
+
   // Clip the bottle vertically to fit it into the picture
   bottleYMin = 0;
   if (pictureY0 < 0) {
@@ -1073,21 +1102,21 @@ static void bubblemon_bottleToPixmap(bubblemon_picture_t *bubblePic)
   if (pictureY0 + bottleH >= pictureH) {
     bottleYMax = bottleH - (pictureY0 + bottleH - pictureH);
   }
-  
+
   // Iterate over the bottle
   for (bottleX = 0; bottleX < bottleW; bottleX++) {
     for (bottleY = bottleYMin; bottleY < bottleYMax; bottleY++) {
       int pictureX = pictureX0 + bottleX;
       int pictureY = pictureY0 + bottleY;
-      
+
       bubblemon_color_t bottlePixel;
       bubblemon_color_t *picturePixel;
-      
+
       // assert(pictureY < pictureH);
-      
+
       bottlePixel = ((bubblemon_color_t*)(msgInBottle.pixel_data))[bottleX + bottleY * bottleW];
       picturePixel = &(bubblePic->pixels[pictureX + pictureY * pictureW]);
-      
+
       *picturePixel = bubblemon_interpolateColor(*picturePixel,
 						 bottlePixel,
 						 bottlePixel.components.a);
@@ -1101,12 +1130,12 @@ static void bubblemon_weedsToPixmap(bubblemon_picture_t *bubblePic)
   int h = bubblePic->height;
 
   int x;
-  
+
   for (x = 0; x < w; x++)
   {
     int y;
     int highestWeedPixel = h - physics.weeds[x].height;
-    
+
     for (y = highestWeedPixel; y < h; y++)
     {
       bubblePic->pixels[y * w + x] = bubblemon_interpolateColor(bubblePic->pixels[y * w + x],
@@ -1120,25 +1149,25 @@ const bubblemon_picture_t *bubblemon_getPicture()
 {
   static const int msecsPerPhysicsFrame = 1000 / PHYSICS_FRAMERATE;
   static int physicalTimeElapsed = 0;
-  
+
   int msecsSinceLastCall;
   mail_status_t mailStatus = mail_getMailStatus();
-  
+
   // Make sure we never try to move things backwards
   do {
     msecsSinceLastCall = bubblemon_getMsecsSinceLastCall();
   } while (msecsSinceLastCall < 0);
-  
+
   // Get the system load
   meter_getLoad(&sysload);
   bubblemon_censorLoad();
-  
+
   // Update the network load statistics.  Since they measure a real
   // time phenomenon, they need to keep track of how much real time
   // has actually passed since last time.  Thus, we provide the
   // uncensored msecsSinceLastCall.
   netload_updateLoadstats(msecsSinceLastCall);
-  
+
   // If a "long" time has passed since the last frame, settle for
   // updating the physics just a bit of the way.
   if (msecsSinceLastCall > 200)
@@ -1160,17 +1189,17 @@ const bubblemon_picture_t *bubblemon_getPicture()
     }
     physicalTimeElapsed -= msecsSinceLastCall;
   }
-  
+
   // Draw the pixels
   bubblemon_environmentToBubbleArray(&bubblePic, BACKGROUND);
   bubblemon_bubbleArrayToPixmap(&bubblePic, BACKGROUND);
-  
+
   bubblemon_weedsToPixmap(&bubblePic);
   bubblemon_bottleToPixmap(&bubblePic);
-  
+
   bubblemon_environmentToBubbleArray(&bubblePic, FOREGROUND);
   bubblemon_bubbleArrayToPixmap(&bubblePic, FOREGROUND);
-  
+
   return &bubblePic;
 }
 
@@ -1184,12 +1213,12 @@ void bubblemon_init(void)
 
   // Initialize the random number generation
   srandom(time(NULL));
-  
+
   // Initialize the load metering
   meter_init(&sysload);
   sysload.cpuLoad = (int *)calloc(sysload.nCpus, sizeof(int));
   assert(sysload.cpuLoad != NULL);
-  
+
   // Initialize the bottle
   physics.bottle_state = GONE;
 }
